@@ -19,12 +19,17 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <math.h>
 #include <stdlib.h>
 #include <string.h>
 #include <glib/gstdio.h>
 
 #include <libebook/libebook.h>
+#include <libedata-book/libedata-book.h>
 
 #include "ews-oab-decoder.h"
 #include "ews-oab-props.h"
@@ -1060,12 +1065,12 @@ ews_oab_decoder_get_contact_from_offset (EwsOabDecoder *eod,
 	return contact;
 }
 
-#include "ews-book-backend-sqlitedb.h"
+#ifdef TEST_BUILD
 
 struct _db_data {
 	GSList *contact_collector;
 	guint collected_length;
-	EwsBookBackendSqliteDB *ebsdb;
+	EBookBackendSqliteDB *summary;
 	const gchar *folderid;
 };
 
@@ -1083,7 +1088,7 @@ ews_test_store_contact (EContact *contact,
 
 	if (data->collected_length == 1000 || percent >= 100) {
 		data->contact_collector = g_slist_reverse (data->contact_collector);
-		ews_book_backend_sqlitedb_add_contacts (data->ebsdb, data->folderid, data->contact_collector, FALSE, error);
+		e_book_backend_sqlitedb_add_contacts (data->summary, data->folderid, data->contact_collector, FALSE, error);
 		g_print ("percent complete %d \n", percent);
 
 		g_slist_foreach (data->contact_collector, (GFunc) g_object_unref, NULL);
@@ -1097,7 +1102,7 @@ gint
 main (gint argc,
       gchar *argv[])
 {
-	EwsBookBackendSqliteDB *ebsdb;
+	EBookBackendSqliteDB *summary;
 	EwsOabDecoder *eod;
 	GError *err = NULL;
 	GTimer *timer;
@@ -1110,12 +1115,12 @@ main (gint argc,
 		return -1;
 	}
 
-	ebsdb = ews_book_backend_sqlitedb_new (argv[2], "dum", "de", "dum", TRUE, NULL);
+	summary = e_book_backend_sqlitedb_new (argv[2], "dum", "de", "dum", TRUE, NULL);
 	eod = ews_oab_decoder_new (argv[1], argv[2], &err);
 
 	data.contact_collector = NULL;
 	data.collected_length = 0;
-	data.ebsdb = ebsdb;
+	data.summary = summary;
 	data.folderid = "de";
 
 	timer = g_timer_new ();
@@ -1130,7 +1135,8 @@ main (gint argc,
 		g_clear_error (&err);
 
 	g_object_unref (eod);
-	g_object_unref (ebsdb);
+	g_object_unref (summary);
 
 	return 0;
 }
+#endif /* TEST_BUILD */
