@@ -545,6 +545,8 @@ add_remote_sources (EEwsBackend *backend)
 			e_server_side_source_set_remote_deletable (
 				E_SERVER_SIDE_SOURCE (source), TRUE);
 			e_source_registry_server_add_source (registry, source);
+		} else {
+			e_source_registry_server_add_source (registry, source);
 		}
 	}
 
@@ -627,6 +629,10 @@ ews_backend_constructed (GObject *object)
 	g_signal_connect (
 		source, "changed",
 		G_CALLBACK (ews_backend_source_changed_cb), object);
+
+	/* Reset the connectable, it steals data from Authentication extension,
+	   where is written incorrect address */
+	e_backend_set_connectable (E_BACKEND (object), NULL);
 }
 
 static void
@@ -640,8 +646,7 @@ ews_backend_populate (ECollectionBackend *backend)
 	ews_backend->priv->need_update_folders = TRUE;
 
 	/* do not do anything, if account is disabled */
-	if (!e_source_get_enabled (source) ||
-	    !e_backend_get_online (E_BACKEND (backend)))
+	if (!e_source_get_enabled (source))
 		return;
 
 	/* For now at least, we don't need to know the
@@ -683,13 +688,6 @@ ews_backend_child_added (ECollectionBackend *backend,
 	extension_name = E_SOURCE_EXTENSION_MAIL_TRANSPORT;
 	is_mail |= e_source_has_extension (child_source, extension_name);
 
-	/* Synchronize mail-related display names with the collection. */
-	if (is_mail)
-		g_object_bind_property (
-			collection_source, "display-name",
-			child_source, "display-name",
-			G_BINDING_SYNC_CREATE);
-
 	/* Synchronize mail-related user with the collection identity. */
 	extension_name = E_SOURCE_EXTENSION_AUTHENTICATION;
 	if (is_mail && e_source_has_extension (child_source, extension_name)) {
@@ -939,11 +937,50 @@ exit:
 	return success;
 }
 
+static gboolean
+ews_backend_get_destination_address (EBackend *backend,
+				     gchar **host,
+				     guint16 *port)
+{
+	CamelEwsSettings *ews_settings;
+	SoupURI *soup_uri;
+	gchar *host_url;
+	gboolean result = FALSE;
+
+	g_return_val_if_fail (port != NULL, FALSE);
+	g_return_val_if_fail (host != NULL, FALSE);
+
+	ews_settings = ews_backend_get_settings (E_EWS_BACKEND (backend));
+	g_return_val_if_fail (ews_settings != NULL, FALSE);
+
+	host_url = camel_ews_settings_dup_hosturl (ews_settings);
+	g_return_val_if_fail (host_url != NULL, FALSE);
+
+	soup_uri = soup_uri_new (host_url);
+	if (soup_uri) {
+		*host = g_strdup (soup_uri_get_host (soup_uri));
+		*port = soup_uri_get_port (soup_uri);
+
+		result = *host && **host;
+		if (!result) {
+			g_free (*host);
+			*host = NULL;
+		}
+
+		soup_uri_free (soup_uri);
+	}
+
+	g_free (host_url);
+
+	return result;
+}
+
 static void
 e_ews_backend_class_init (EEwsBackendClass *class)
 {
 	GObjectClass *object_class;
-	ECollectionBackendClass *backend_class;
+	EBackendClass *backend_class;
+	ECollectionBackendClass *collection_backend_class;
 
 	g_type_class_add_private (class, sizeof (EEwsBackendPrivate));
 
@@ -952,13 +989,16 @@ e_ews_backend_class_init (EEwsBackendClass *class)
 	object_class->finalize = ews_backend_finalize;
 	object_class->constructed = ews_backend_constructed;
 
-	backend_class = E_COLLECTION_BACKEND_CLASS (class);
-	backend_class->populate = ews_backend_populate;
-	backend_class->dup_resource_id = ews_backend_dup_resource_id;
-	backend_class->child_added = ews_backend_child_added;
-	backend_class->child_removed = ews_backend_child_removed;
-	backend_class->create_resource_sync = ews_backend_create_resource_sync;
-	backend_class->delete_resource_sync = ews_backend_delete_resource_sync;
+	collection_backend_class = E_COLLECTION_BACKEND_CLASS (class);
+	collection_backend_class->populate = ews_backend_populate;
+	collection_backend_class->dup_resource_id = ews_backend_dup_resource_id;
+	collection_backend_class->child_added = ews_backend_child_added;
+	collection_backend_class->child_removed = ews_backend_child_removed;
+	collection_backend_class->create_resource_sync = ews_backend_create_resource_sync;
+	collection_backend_class->delete_resource_sync = ews_backend_delete_resource_sync;
+
+	backend_class = E_BACKEND_CLASS (class);
+	backend_class->get_destination_address = ews_backend_get_destination_address;
 
 	/* This generates an ESourceCamel subtype for CamelEwsSettings. */
 	e_source_camel_generate_subtype ("ews", CAMEL_TYPE_EWS_SETTINGS);
@@ -983,6 +1023,10 @@ e_ews_backend_init (EEwsBackend *backend)
 	g_mutex_init (&backend->priv->folders_lock);
 	g_mutex_init (&backend->priv->sync_state_lock);
 	g_mutex_init (&backend->priv->connection_lock);
+
+	g_signal_connect (
+		backend, "notify::online",
+		G_CALLBACK (ews_backend_populate), NULL);
 }
 
 void
@@ -1169,6 +1213,22 @@ e_ews_backend_sync_folders_sync (EEwsBackend *backend,
 
 	g_return_val_if_fail (E_IS_EWS_BACKEND (backend), FALSE);
 
+	if (!e_backend_get_online (E_BACKEND (backend))) {
+		SyncFoldersClosure *closure;
+
+		/* This takes ownership of the folder lists. */
+		closure = g_slice_new0 (SyncFoldersClosure);
+		closure->backend = g_object_ref (backend);
+
+		/* Process the results from an idle callback. */
+		g_idle_add_full (
+			G_PRIORITY_DEFAULT_IDLE,
+			ews_backend_sync_folders_idle_cb, closure,
+			(GDestroyNotify) sync_folders_closure_free);
+
+		return TRUE;
+	}
+
 	connection = e_ews_backend_ref_connection_sync (
 		backend, cancellable, error);
 
